﻿using Hotline.CallCenter.Tels;
using Hotline.FlowEngine.Notifications;
using Hotline.FlowEngine.WfModules;
using Hotline.FlowEngine.Workflows;
using Hotline.KnowledgeBase;
using Hotline.Orders;
using Hotline.Settings;
using MediatR;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.FlowEngine;

public class EndWorkflowHandler : INotificationHandler<EndWorkflowNotify>
{

    private readonly IKnowledgeDomainService _knowledgeDomainService;
    private readonly IOrderDomainService _orderDomainService;
    private readonly ITelDomainService _telDomainService;
    private readonly IWorkflowDomainService _workflowDomainService;
    private readonly ISystemOrganizeRepository _orgRepository;

    public EndWorkflowHandler(
        IKnowledgeDomainService knowledgeDomainService,
        IOrderDomainService orderDomainService,
        ITelDomainService telDomainService,
        IWorkflowDomainService workflowDomainService,
        ISystemOrganizeRepository orgRepository
        )
    {
        _knowledgeDomainService = knowledgeDomainService;
        _orderDomainService = orderDomainService;
        _telDomainService = telDomainService;
        _workflowDomainService = workflowDomainService;
        _orgRepository = orgRepository;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(EndWorkflowNotify notification, CancellationToken cancellationToken)
    {
        var workflow = notification.Workflow;

        switch (workflow.ModuleCode)
        {
            case WorkflowModuleConsts.KnowledgeAdd://新增知识库
            //case WorkflowModuleConsts.KnowledgeUpdate://修改知识库
            case WorkflowModuleConsts.KnowledgeDelete://删除知识库
                await _knowledgeDomainService.EndWorkKnowledge(workflow, cancellationToken);
                break;

            case WorkflowModuleConsts.TelRestApply:
                await _telDomainService.TelRestApplyPassAsync(workflow.ExternalId, cancellationToken);
                break;

            case WorkflowModuleConsts.OrderManage:
                var levelOneOrg = workflow.ActualHandleOrgCode.GetOrgLevel();
                var org = await _orgRepository.GetAsync(d => d.OrgCode == levelOneOrg, cancellationToken);
                if (org is null)
                    throw new UserFriendlyException($"无效部门编码, levelOneOrg: {levelOneOrg}", "无效部门编码");

                await _workflowDomainService.UpdateOrgLevelOneAsync(workflow, org.OrgCode, org.OrgName, cancellationToken);

                await _orderDomainService.ManageFlowEndAsync(workflow.ExternalId, cancellationToken);
                break;
        }
    }
}