﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.CallCenter.Tels;
using Hotline.FlowEngine.Notifications;
using Hotline.FlowEngine.WfModules;
using Hotline.KnowledgeBase;
using Hotline.Orders;
using MapsterMapper;
using MediatR;
using Microsoft.Extensions.Logging;

namespace Hotline.Application.Handlers.FlowEngine
{
    public class PreviousStepHandler : INotificationHandler<PreviousNotify>
    {
        private readonly IOrderDomainService _orderDomainService;
        private readonly IMapper _mapper;

        public PreviousStepHandler(
            IOrderDomainService orderDomainService,
            IMapper mapper)
        {
            _orderDomainService = orderDomainService;
            _mapper = mapper;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(PreviousNotify notification, CancellationToken cancellationToken)
        {
            //todo 1.query order 2.remove depCode from assignDepCodes, userId from assignUserIds
            var workflow = notification.Workflow;
            var data = notification.Dto;

            switch (workflow.ModuleCode)
            {
                case WorkflowModuleConsts.OrderManage:
                    var order = await _orderDomainService.GetOrderAsync(workflow.ExternalId, cancellationToken);
                    _mapper.Map(workflow, order);
                    //todo 退回是否推送省12345？退回/撤销/跳转操作是否影响省12345数据？
                    await _orderDomainService.ManageFlowPreviousAsync(order, false, workflow.IsInCountersign(), cancellationToken);
                    break;
                case WorkflowModuleConsts.KnowledgeAdd:
                case WorkflowModuleConsts.KnowledgeUpdate:
                case WorkflowModuleConsts.KnowledgeDelete:
                case WorkflowModuleConsts.TelRestApply:
                    break;
            }
        }
    }
}
