﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.FlowEngine;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using XF.Domain.Entities;

namespace Hotline.Orders
{
    public interface IOrderDomainService
    {
        Task<Order> GetOrderAsync(string? orderId, CancellationToken cancellationToken);

        Task<string> AddAsync(Order order, CancellationToken cancellationToken);

        /// <summary>
        /// 归档
        /// </summary>
        Task FileAsync(string? orderId, CancellationToken cancellationToken);

        /// <summary>
        /// 接办工单（查看详情视为接办）
        /// </summary>
        Task AcceptAsync(string? orderId, CancellationToken cancellationToken);

        /// <summary>
        /// 工单办理流程开始(流程开始后触发)
        /// </summary>
        Task ManageFlowStartAsync(FlowAssignInfo assignInfo, Order order, bool isInCountersign, CancellationToken cancellationToken);

        /// <summary>
        /// 工单办理流程流转(每个节点办理都会触发)
        /// </summary>
        Task<OrderDto> ManageFlowNextAsync(FlowAssignInfo assignInfo, Order order, bool isFromCenterToOrg, bool isInCountersign, CancellationToken cancellationToken);

        /// <summary>
        /// 工单办理流程退回操作
        /// </summary>
        Task<OrderDto> ManageFlowPreviousAsync(Order order, bool isFromCenterToOrg, bool isInCountersign, CancellationToken cancellationToken);

        /// <summary>
        /// 工单最终办理（此完结流程并未结束）
        /// </summary>
        /// <remarks>
        /// 需求：工单实际办理部门办理完成视为工单最终办理完结，
        /// 实际办理部门指：1.第一个汇总节点的前一个非汇总节点代表的办理部门 2.汇总以后如果再次开启会签需将工单回退到未办理完结的状态重新等待下一个汇总节点
        /// </remarks>
        /// <returns></returns>
        Task FinalManageAsync(string? orderId, CancellationToken cancellationToken);

        /// <summary>
        /// 撤回最终办理（汇总以后又重新指派到非汇总汇总节点办理的场景）
        /// </summary>
        /// <returns></returns>
        Task RecallFinalManageAsync(string? orderId, CancellationToken cancellationToken);

        /// <summary>
        /// 工单办理流程流转到结束节点
        /// </summary>
        Task ManageFlowEndAsync(string? orderId, CancellationToken cancellationToken);

        /// <summary>
        /// 流程跳转
        /// </summary>
        /// <param name="workflowId"></param>
        /// <param name="assignInfo"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task ManageFlowJumpAsync(string workflowId, FlowAssignInfo assignInfo, CancellationToken cancellationToken);
    }
}
