﻿using Hotline.Share.Enums.Order;
using Hotline.Users;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders;

/// <summary>
/// 已回访工单
/// </summary>
public class OrderVisit : CreationEntity
{
    /// <summary>
    /// 工单编码（冗余）
    /// </summary>
    public string No { get; set; }

    /// <summary>
    /// 工单ID
    /// </summary>
    public string OrderId { get; set; }

    /// <summary>
    /// 工单
    /// </summary>
    [Navigate(NavigateType.OneToOne,nameof(OrderId))]
    public Order Order { get; set; }

    /// <summary>
    /// 回访状态
    /// </summary>
    public EVisitState VisitState { get; set; }

    /// <summary>
    /// 回访方式
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public EVisitType? VisitType { get; set; }
    

    /// <summary>
    /// 发布时间
    /// </summary>
    public DateTime PublishTime { get; set; }

    /// <summary>
    /// 回访人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string EmployeeId { get; set; }

    /// <summary>
    /// 回访人（对象）
    /// </summary>
    [Navigate(NavigateType.OneToOne, nameof(EmployeeId))]
    public User Employee { get; set; }

    /// <summary>
    /// 是否接通
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public bool? IsPutThrough { get; set; }

    /// <summary>
    /// 回访时间
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public DateTime? VisitTime { get; set; }


    /// <summary>
    /// 回访明细
    /// </summary>
    [SugarColumn(IsIgnore = true)]
    public List<OrderVisitDetail>? VisitDetails { get; set; }

}